<?php

namespace Drupal\book_moderation_sync\Hook;

use Drupal\Core\Entity\EntityInterface;
use Drupal\node\NodeInterface;

/**
 * Interface for book moderation synchronization operations.
 */
interface BookModerationHooksInterface {

  /**
   * Processes node presave operations for book moderation.
   *
   * @param \Drupal\node\NodeInterface $entity
   *   The node being saved.
   */
  public function nodePresave(NodeInterface $entity): void;

  /**
   * Processes entity deletion for book moderation.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity being deleted.
   */
  public function entityPredelete(EntityInterface $entity): void;

  /**
   * Deletes child nodes of a book.
   *
   * @param \Drupal\node\NodeInterface $node
   *   The parent node.
   */
  public function deleteBookChildren(NodeInterface $node): void;

}
